package com.heyu.api.data.dao.vv;
/**
* <p>
* 类目表 服务类
* </p>
*
* @author quyixiao
* @since 2025-08-24
*/

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.heyu.api.data.entity.vv.VvAppCategoryEntity;
import com.lz.mybatis.plugin.annotations.IN;
import com.lz.mybatis.plugin.annotations.OrderBy;
import com.lz.mybatis.plugin.annotations.OrderType;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface VvAppCategoryDao extends BaseMapper<VvAppCategoryEntity> {


	VvAppCategoryEntity selectVvAppCategoryById(@Param("id")Long id);


	Long insertVvAppCategory(VvAppCategoryEntity vvAppCategory);


	Long insertOrUpdateVvAppCategory(VvAppCategoryEntity vvAppCategory);


	int updateVvAppCategoryById(VvAppCategoryEntity vvAppCategory);


	int updateCoverVvAppCategoryById(VvAppCategoryEntity vvAppCategory);


	int deleteVvAppCategoryById(@Param("id")Long id);



	List<VvAppCategoryEntity> selectVvCategoryAll();


	@OrderBy(value={VvAppCategoryEntity.default_sort},type={OrderType.ASC})
	List<VvAppCategoryEntity> selectVvCategoryByParentId(Integer parentId);

	List<VvAppCategoryEntity> selectVvCategoryByIds(@IN List<Long> id);
}